OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Mapa 'config' nima določenih ustreznih dovoljenj za pisanje!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v nastavitveno mapo.",
    "See %s" : "Oglejte si %s",
    "Sample configuration detected" : "Zaznana je neustrezna preizkusna nastavitev",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Zaznano je, da je bila v sistem kopirana datoteka z enostavno nastavitvijo. To lahko vpliva na namestitev in zato možnost ni podprta. Pred spremembami datoteke config.php si natančno preberite dokumentacijo.",
    "%1$s and %2$s" : "%1$s in %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s in %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s in %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s in %5$s",
    "Enterprise bundle" : "Poslovni paket",
    "Groupware bundle" : "Paket za skupinsko delo",
    "Social sharing bundle" : "Paket družbene izmenjave",
    "PHP %s or higher is required." : "Zahtevana je različica PHP %s ali višja.",
    "PHP with a version lower than %s is required." : "Zahtevana je različica PHP manj kot %s.",
    "%sbit or higher PHP required." : "Zahtevana je različica PHP %s ali višja.",
    "Following databases are supported: %s" : "Podprte so navedene podatkovne zbirke: %s",
    "The command line tool %s could not be found" : "Orodja ukazne vrstice %s ni mogoče najti",
    "The library %s is not available." : "Knjižnica %s ni na voljo.",
    "Following platforms are supported: %s" : "Podprta so okolja: %s",
    "Server version %s or higher is required." : "Zahtevana je različica strežnika %s ali višja.",
    "Server version %s or lower is required." : "Zahtevana je različica strežnika %s ali nižja.",
    "Authentication" : "Overitev",
    "Unknown filetype" : "Neznana vrsta datoteke",
    "Invalid image" : "Neveljavna slika",
    "Avatar image is not square" : "Slika podobe ni kvadratna",
    "today" : "danes",
    "tomorrow" : "jutri",
    "yesterday" : "včeraj",
    "_in %n day_::_in %n days_" : ["čez %n dan","čez %n dneva","čez %n dni","čez %n dni"],
    "_%n day ago_::_%n days ago_" : ["pred %n dnevom","pred %n dnevoma","pred %n dnevi","pred %n dnevi"],
    "next month" : "naslednji mesec",
    "last month" : "zadnji mesec",
    "_in %n month_::_in %n months_" : ["čez %n mesec","čez %n meseca","čez %n mesece","čez %n mesecev"],
    "_%n month ago_::_%n months ago_" : ["pred %n mesecem","pred %n mesecema","pred %n meseci","pred %n meseci"],
    "next year" : "naslednje leto",
    "last year" : "lansko leto",
    "_in %n year_::_in %n years_" : ["čez %n leto","čez %n leti","čez %n leta","čez %n let"],
    "_%n year ago_::_%n years ago_" : ["pred %n letom","pred %n letoma","pred %n leti","pred %n leti"],
    "_in %n hour_::_in %n hours_" : ["čez %n uro","čez %n uri","čez %n ure","čez %n ur"],
    "_%n hour ago_::_%n hours ago_" : ["pred %n uro","pred %n urama","pred %n urami","pred %n urami"],
    "_in %n minute_::_in %n minutes_" : ["čez %n minuto","čez %n minuti","čez %n minute","čez %n minut"],
    "_%n minute ago_::_%n minutes ago_" : ["pred %n minuto","pred %n minutama","pred %n minutami","pred %n minutami"],
    "in a few seconds" : "čez nekaj sekund",
    "seconds ago" : "pred nekaj sekundami",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul z ID: %s ne obstaja. Omogočite ga med nastavitvami, ali pa stopite v stik s skrbnikom sistema.",
    "File name is a reserved word" : "Ime datoteke je zadržana beseda",
    "File name contains at least one invalid character" : "Ime datoteke vsebuje vsaj en nedovoljen znak.",
    "File name is too long" : "Ime datoteke je predolgo",
    "Dot files are not allowed" : "Skrite datoteke niso dovoljene",
    "Empty filename is not allowed" : "Prazno polje imena datoteke ni dovoljeno.",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Programa »%s« ni mogoče namestiti, ker datoteke appinfo ni mogoče brati.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Programa »%s« ni mogoče namestiti, ker ni združljiv z nameščeno različico strežnika.",
    "__language_name__" : "Slovenščina",
    "This is an automatically sent email, please do not reply." : "To sporočilo je samodejno poslano, nanj se nima smisla odzvati.",
    "Help" : "Pomoč",
    "Apps" : "Programi",
    "Settings" : "Nastavitve",
    "Log out" : "Odjava",
    "Users" : "Uporabniki",
    "Unknown user" : "Neznan uporabnik",
    "Overview" : "Splošni pregled",
    "Basic settings" : "Osnovne nastavitve",
    "Sharing" : "Souporaba",
    "Security" : "Varnost",
    "Groupware" : "Skupinsko delo",
    "Additional settings" : "Dodatne nastavitve",
    "Personal info" : "Osebni podatki",
    "Mobile & desktop" : "Mobilni in namizni dostop",
    "%s enter the database username and name." : "%s - vnos uporabniškega imena in imena podatkovne zbirke.",
    "%s enter the database username." : "%s - vnos uporabniškega imena podatkovne zbirke.",
    "%s enter the database name." : "%s - vnos imena podatkovne zbirke.",
    "%s you may not use dots in the database name" : "%s - v imenu podatkovne zbirke ni dovoljeno uporabljati pik.",
    "Oracle connection could not be established" : "Povezave s sistemom Oracle ni mogoče vzpostaviti.",
    "Oracle username and/or password not valid" : "Uporabniško ime ali geslo Oracle ni veljavno",
    "PostgreSQL username and/or password not valid" : "Uporabniško ime ali geslo PostgreSQL ni veljavno",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Sistem Mac OS X ni podprt, zato %s v tem okolju ne bo deloval zanesljivo. Program uporabljate na lastno odgovornost! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Za najbolj še rezultate je priporočljivo uporabljati strežnik GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Videti je, da je dejavna seja %s zagnana v 32-bitnem okolju PHP in, da je v datoteki php.ini nastavljen open_basedir . Tako delovanje ni priporočljivo, saj se lahko pojavijo težave z datotekami, večjimi od 4GB.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraniti je treba nastavitev open_basedir v datoteki php.ini ali pa preklopiti na 64-bitno okolje PHP.",
    "Set an admin username." : "Nastavi uporabniško ime skrbnika.",
    "Set an admin password." : "Nastavi skrbniško geslo.",
    "Can't create or write into the data directory %s" : "Ni mogoče zapisati podatkov v podatkovno mapo %s",
    "Invalid Federated Cloud ID" : "Neveljaven ID zveznega oblaka ownCloud",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
    "Sharing backend %s not found" : "Ozadnjega programa %s za souporabo ni mogoče najti",
    "Sharing backend for %s not found" : "Ozadnjega programa za souporabo za %s ni mogoče najti",
    "Open »%s«" : "Odpri »%s«",
    "You are not allowed to share %s" : "Omogočanje souporabe %s brez ustreznih dovoljenj ni mogoče.",
    "Expiration date is in the past" : "Datum preteka je že mimo!",
    "Could not find category \"%s\"" : "Kategorije \"%s\" ni mogoče najti.",
    "Sunday" : "nedelja",
    "Monday" : "ponedeljek",
    "Tuesday" : "torek",
    "Wednesday" : "sreda",
    "Thursday" : "četrtek",
    "Friday" : "petek",
    "Saturday" : "sobota",
    "Sun." : "ned",
    "Mon." : "pon",
    "Tue." : "tor",
    "Wed." : "sre",
    "Thu." : "čet",
    "Fri." : "pet",
    "Sat." : "sob",
    "Su" : "ne",
    "Mo" : "po",
    "Tu" : "to",
    "We" : "sr",
    "Th" : "če",
    "Fr" : "pe",
    "Sa" : "so",
    "January" : "januar",
    "February" : "februar",
    "March" : "marec",
    "April" : "april",
    "May" : "maj",
    "June" : "junij",
    "July" : "julij",
    "August" : "avgust",
    "September" : "september",
    "October" : "oktober",
    "November" : "november",
    "December" : "december",
    "Jan." : "jan",
    "Feb." : "feb",
    "Mar." : "mar",
    "Apr." : "apr",
    "May." : "maj",
    "Jun." : "jun",
    "Jul." : "jul",
    "Aug." : "avg",
    "Sep." : "sep",
    "Oct." : "okt",
    "Nov." : "nov",
    "Dec." : "dec",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "V uporabniškem imenu je dovoljeno uporabiti le znake: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
    "Username contains whitespace at the beginning or at the end" : "Uporabniško ime vsebuje presledni znak na začetku ali na koncu imena.",
    "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
    "The username is already being used" : "Vpisano uporabniško ime je že v uporabi",
    "User disabled" : "Uporabnik je onemogočen",
    "Login canceled by app" : "Program onemogoča prijavo",
    "a safe home for all your data" : "Varno okolje za vaše podatke!",
    "File is currently busy, please try again later" : "Datoteka je trenutno v uporabi. Poskusite znova kasneje.",
    "Can't read file" : "Datoteke ni mogoče prebrati.",
    "Application is not enabled" : "Program ni omogočen",
    "Authentication error" : "Napaka overjanja",
    "Token expired. Please reload page." : "Žeton je potekel. Stran je treba ponovno naložiti.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ni nameščenih programnikov podatkovnih zbirk (sqlite, mysql, ali postgresql).",
    "Cannot write into \"config\" directory" : "Mapa 'config' nima nastavljenih ustreznih dovoljenj za pisanje!",
    "Cannot write into \"apps\" directory" : "Mapa \"apps\" nima nastavljenih ustreznih dovoljenj za pisanje!",
    "Setting locale to %s failed" : "Nastavljanje jezikovnih določil na %s je spodletelo.",
    "Please install one of these locales on your system and restart your webserver." : "Namestiti je treba podporo za vsaj eno od navedenih jezikovnih določil v sistemu in nato ponovno zagnati spletni strežnik.",
    "Please ask your server administrator to install the module." : "Obvestite skrbnika strežnika, da je treba namestiti manjkajoč modul.",
    "PHP module %s not installed." : "Modul PHP %s ni nameščen.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Nastavitev PHP \"%s\" ni nastavljena na \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Nastavitev tega parametra v <bold>php.ini</bold> bo vzpostavilo ponovno delovanje NextCloud",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je nastavljeno na \"%s\" namesto pričakovane vrednosti \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Za reštev te težave nastavi <code>mbstring.func_overload</code> na <code>0</code> v tvojem php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 mora iti vsaj 2.7.0. Trenutno je nameščena %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Za rešitev te težave je treba posodobiti knjižnico libxml2 in nato ponovno zagnati spletni strežnik.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : " Izgleda, da je PHP nastavljen, da odreže znake v 'inline doc' blokih. To bo povzročilo, da nekateri osnovni moduli ne bodo dosegljivi.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Napako je najverjetneje povzročil predpomnilnik ali pospeševalnik, kot sta Zend OPcache ali eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Ali so bili moduli PHP nameščeni, pa so še vedno označeni kot manjkajoči?",
    "Please ask your server administrator to restart the web server." : "Obvestite skrbnika strežnika, da je treba ponovno zagnati spletni strežnik.",
    "PostgreSQL >= 9 required" : "Zahtevana je različica PostgreSQL >= 9.",
    "Please upgrade your database version" : "Posodobite različico podatkovne zbirke.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom.",
    "Check the value of \"datadirectory\" in your configuration" : "V konfiguraciji preverite nastavitev \"datadirectory\"",
    "Could not obtain lock type %d on \"%s\"." : "Ni mogoče pridobiti zaklepa %d na \"%s\".",
    "Storage unauthorized. %s" : "Dostop do shrambe ni overjen. %s",
    "Storage incomplete configuration. %s" : "Nepopolna nastavitev shrambe. %s",
    "Storage connection error. %s" : "Napaka povezave do shrambe. %s",
    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
    "Storage connection timeout. %s" : "Povezava do shrambe je časovno potekla. %s",
    "Create" : "Ustvari",
    "Change" : "Spremeni",
    "Delete" : "Izbriši",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Omogočanje souporabe %s je spodletelo, ker ozadnji program ne dopušča souporabe vrste %i.",
    "Sharing %s failed, because the file does not exist" : "Souporaba %s je spodletela, ker ta datoteka ne obstaja",
    "Sharing %s failed, because you can not share with yourself" : "Nastavitev %s souporabe je spodletela, ker souporaba s samim seboj ni mogoča.",
    "You need to provide a password to create a public link, only protected links are allowed" : "Navesti je treba geslo za ustvarjanje javne povezave, saj so dovoljene le zaščitene.",
    "Sharing %s failed, because sharing with links is not allowed" : "Nastavljanje souporabe %s je spodletelo, ker souporaba preko povezave ni dovoljena.",
    "Not allowed to create a federated share with the same user" : "Ni dovoljeno ustvariti souporabe zveznega oblaka z istim uporabnikom",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ni mogoče določiti datuma preteka. Ni dovoljeno, da so mape ali datoteke, dodeljene v souporabo, v souporabi po %s.",
    "Cannot set expiration date. Expiration date is in the past" : "Ni mogoče nastaviti datuma preteka. Ta datum je že preteklost.",
    "Sharing failed, because the user %s is the original sharer" : "Nastavitev souporabe je spodletela, ker je uporabnik %s souporabo izvorno nastavil.",
    "Sharing %s failed, because resharing is not allowed" : "Nastavljanje souporabe %s je spodletelo, ker nadaljnje omogočanje souporabe ni dovoljeno.",
    "Sharing %s failed, because the file could not be found in the file cache" : "Nastavljanje souporabe %s je spodletelo, ker v predpomnilniku zahtevana datoteka ne obstaja."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
